@@ -7,7 +7,7 @@ use warnings 'all';
 ###############################################################################
 # METADATA
 our $AUTHORITY = 'cpan:DOUGDUDE';
-our $VERSION   = '0.002';
+our $VERSION   = '0.003';
 
 ###############################################################################
 # MOOSE
@@ -21,7 +21,7 @@ use Net::NSCA::Client::Library qw(InitializationVector);
 ###############################################################################
 # MODULES
 use Convert::Binary::C 0.74;
-use Crypt::Random;
+use Data::Rand::Obscure 0.020;
 use Readonly 1.03;
 
 ###############################################################################
@@ -100,9 +100,8 @@ sub to_string {
 sub _build_initialization_vector {
 	my ($self) = @_;
 
-	return Crypt::Random::makerandom_octet(
-		Length   => $INITIALIZATION_VECTOR_LENGTH,
-		Strength => 1,
+	return Data::Rand::Obscure::create_bin(
+		length => $INITIALIZATION_VECTOR_LENGTH,
 	);
 }
 
@@ -193,7 +192,7 @@ protocol
 
 =head1 VERSION
 
-This documentation refers to L<Net::NSCA::Client::InitialPacket> version 0.002
+This documentation refers to L<Net::NSCA::Client::InitialPacket> version 0.003
 
 =head1 SYNOPSIS
 
@@ -281,7 +280,7 @@ This is the length of the L</initialization_vector>.
 
 =item * L<Convert::Binary::C> 0.74
 
-=item * L<Crypt::Random>
+=item * L<Data::Rand::Obscure> 0.020
 
 =item * L<Moose> 0.89
 
